@@ -43,6 +43,9 @@ const Application = new Lang.Class({
     },
 
     vfunc_startup: function() {
+        let resource = Gio.Resource.load(Config.RESOURCE_DIR + '/polari.gresource');
+        resource._register();
+
         this.parent();
         String.prototype.format = Format.format;
 
@@ -55,9 +58,6 @@ const Application = new Lang.Class({
         let w = new Polari.FixedSizeFrame(); // register gtype
         w.destroy();
 
-        let resource = Gio.Resource.load(Config.RESOURCE_DIR + '/polari.gresource');
-        resource._register();
-
         this._chatroomManager = ChatroomManager.getDefault();
         this._accountsMonitor = AccountsMonitor.getDefault();
 
@@ -72,10 +72,6 @@ const Application = new Lang.Class({
         this.notificationQueue = new AppNotifications.NotificationQueue();
         this.commandOutputQueue = new AppNotifications.CommandOutputQueue();
 
-        let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/polari/app-menu.ui');
-        this.set_app_menu(builder.get_object('app-menu'));
-
         let actionEntries = [
           { name: 'room-menu',
             activate: Lang.bind(this, this._onToggleAction),
@@ -164,7 +160,7 @@ const Application = new Lang.Class({
             }));
 
         let provider = new Gtk.CssProvider();
-        let uri = 'resource:///org/gnome/polari/application.css';
+        let uri = 'resource:///org/gnome/Polari/application.css';
         let file = Gio.File.new_for_uri(uri);
         try {
             provider.load_from_file(Gio.File.new_for_uri(uri));
