@@ -3,6 +3,7 @@ const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const Pango = imports.gi.Pango;
+const Polari = imports.gi.Polari;
 const Tp = imports.gi.TelepathyGLib;
 const Tpl = imports.gi.TelepathyLogger;
 
@@ -177,6 +178,10 @@ const ChatView = new Lang.Class({
         context.save();
         context.add_class('dim-label');
         let dimColor = context.get_color(Gtk.StateFlags.NORMAL);
+        context.restore();
+
+        context.save();
+        context.add_class('view');
         let selectedColor = context.get_background_color(Gtk.StateFlags.SELECTED);
         context.restore();
 
@@ -388,13 +393,36 @@ const ChatView = new Lang.Class({
         delete this._pending[id];
     },
 
-    _handleLinkClicks: function(view, event) {
-        let [, button] = event.get_button();
-        if (button != Gdk.BUTTON_PRIMARY)
-            return Gdk.EVENT_PROPAGATE;
+    _showUrlContextMenu: function(url, button, time) {
+        let menu = new Gtk.Menu();
 
+        let item = new Gtk.MenuItem({ label: _("Open Link") });
+        item.connect('activate',
+            function() {
+                Gio.AppInfo.launch_default_for_uri(url, null);
+            });
+        menu.append(item);
+
+        item = new Gtk.MenuItem({ label: _("Copy Link Address") });
+        item.connect('activate',
+            function() {
+                let clipboard = Polari.util_get_clipboard_for_widget(item);
+                clipboard.set_text(url, -1);
+            });
+        menu.append(item);
+
+        menu.show_all();
+        menu.popup(null, null, null, button, time);
+    },
+
+    _handleLinkClicks: function(view, event) {
         let isPress = event.get_event_type() == Gdk.EventType.BUTTON_PRESS;
 
+        let [, button] = event.get_button();
+        if (button != Gdk.BUTTON_PRIMARY &&
+            (button != Gdk.BUTTON_SECONDARY || !isPress))
+            return Gdk.EVENT_PROPAGATE;
+
         if (isPress)
             this._clickedUrl = null;
 
@@ -407,12 +435,16 @@ const ChatView = new Lang.Class({
         for (let i = 0; i < tags.length; i++) {
             let url = tags[i]._url;
             if (url) {
+                if (url.indexOf(':') == -1)
+                    url = 'http://' + url;
+
                 if (isPress) {
-                    this._clickedUrl = url;
+                    if (button == Gdk.BUTTON_PRIMARY)
+                        this._clickedUrl = url;
+                    else
+                        this._showUrlContextMenu(url, button, event.get_time());
                     return Gdk.EVENT_STOP;
                 } else if (this._clickedUrl == url) {
-                    if (url.indexOf(':') == -1)
-                        url = 'http://' + url;
                     Gio.AppInfo.launch_default_for_uri(url, null);
                     return Gdk.EVENT_STOP;
                 }
@@ -555,7 +587,16 @@ const ChatView = new Lang.Class({
         let date = GLib.DateTime.new_from_unix_local(timestamp);
         let now = GLib.DateTime.new_now_local();
 
-        let daysAgo = now.difference(date) / GLib.TIME_SPAN_DAY;
+        // 00:01 actually, just to be safe
+        let todayMidnight = GLib.DateTime.new_local(now.get_year(),
+                                                    now.get_month(),
+                                                    now.get_day_of_month(),
+                                                    0, 1, 0);
+        let dateMidnight = GLib.DateTime.new_local(date.get_year(),
+                                                   date.get_month(),
+                                                   date.get_day_of_month(),
+                                                   0, 1, 0);
+        let daysAgo = todayMidnight.difference(dateMidnight) / GLib.TIME_SPAN_DAY;
 
         let format;
         let desktopSettings = new Gio.Settings({ schema: 'org.gnome.desktop.interface' });
