@@ -1,6 +1,7 @@
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
+const Tp = imports.gi.TelepathyGLib;
 const Tpl = imports.gi.TelepathyLogger;
 
 const AccountsMonitor = imports.accountsMonitor;
@@ -20,6 +21,8 @@ const JoinDialog = new Lang.Class({
     _init: function() {
         this._createWidget();
 
+        this._settings = new Gio.Settings({ schema: 'org.gnome.polari' });
+
         this._accountsMonitor = AccountsMonitor.getDefault();
 
         this._accounts = {};
@@ -50,11 +53,13 @@ const JoinDialog = new Lang.Class({
 
         this._updateConnectionCombo();
         this._updateCanConfirm();
+
+        this._nameEntry.grab_focus();
     },
 
     _createWidget: function() {
         let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/polari/join-room-dialog.ui');
+        builder.add_from_resource('/org/gnome/Polari/join-room-dialog.ui');
 
         this.widget = builder.get_object('join_room_dialog');
 
@@ -149,6 +154,9 @@ const JoinDialog = new Lang.Class({
         let selected = this._connectionCombo.get_active_text();
         let account = this._accounts[selected];
 
+        this._settings.set_string('last-used-account',
+                                  account.get_object_path());
+
         let room = this._nameEntry.get_text();
         if (room[0] != '#')
             room = '#' + room;
@@ -172,17 +180,26 @@ const JoinDialog = new Lang.Class({
         for (let i = 0; i < names.length; i++)
             this._connectionCombo.append_text(names[i]);
         this._connectionCombo.sensitive = names.length > 1;
-        this._connectionCombo.set_active(0);
+
+        let factory = Tp.AccountManager.dup().get_factory();
+        let lastUsed = factory.ensure_account(this._settings.get_string('last-used-account'), []);
+        let activeIndex = lastUsed ? names.indexOf(lastUsed.display_name) : 0;
+        this._connectionCombo.set_active(activeIndex);
     },
 
     _updateCanConfirm: function() {
+        let sensitive;
+
         if (this._page == DialogPage.MAIN) {
-            let sensitive = this._connectionCombo.get_active() > -1  &&
-                            this._nameEntry.get_text_length() > 0;
-            this._confirmButton.sensitive = sensitive;
+            sensitive = this._connectionCombo.get_active() > -1  &&
+                        this._nameEntry.get_text_length() > 0;
         } else {
-            this._confirmButton.sensitive = this._details.canConfirm;
+            sensitive = this._details.canConfirm;
         }
+
+        this._confirmButton.sensitive = sensitive;
+        this.widget.set_default_response(sensitive ? Gtk.ResponseType.OK
+                                                   : Gtk.ResponseType.NONE);
     },
 
     get _page() {
@@ -198,8 +215,6 @@ const JoinDialog = new Lang.Class({
         if (isMain)
             this._details.reset();
 
-        this._confirmButton.grab_default();
-
         this._backButton.visible = !isMain;
         this._cancelButton.visible = isMain;
         this._titlebar.title = isMain ? _("Join Chat Room")
