@@ -162,7 +162,7 @@ const MainWindow = new Lang.Class({
 
     _onSelectionModeChanged: function() {
         let enabled = this._selectionModeAction.state.get_boolean();
-        this._selectionRevealer.reveal_child = enabled;
+        this._selectionActionBar.visible = enabled;
         this._joinMenuButton.visible = !enabled;
         this._showUserListButton.visible = !enabled;
         this._userListAction.enabled = !enabled;
@@ -192,7 +192,7 @@ const MainWindow = new Lang.Class({
         notification.widget.connect('destroy',
             function() {
                 app.unmark_busy();
-		delete account._connectingNotification;
+                delete account._connectingNotification;
             });
     },
 
@@ -243,7 +243,7 @@ const MainWindow = new Lang.Class({
 
     _createWidget: function(app) {
         let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/polari/main-window.ui');
+        builder.add_from_resource('/org/gnome/Polari/main-window.ui');
 
         this.window = builder.get_object('main_window');
         this.window.application = app;
@@ -253,13 +253,32 @@ const MainWindow = new Lang.Class({
         this._roomStack = new RoomStack.RoomStack(sizeGroup);
         overlay.add(this._roomStack.widget);
 
+        overlay.add_overlay(app.notificationQueue.widget);
+        overlay.add_overlay(app.commandOutputQueue.widget);
+
+        // command output notifications should not pop up over
+        // the input area, but appear to emerge from it, so
+        // set up an appropriate margin - this relies on the
+        // last widget added to the size group at this point
+        // is the room stack's placeholder entry, which will
+        // never be destroyed
+        sizeGroup.get_widgets()[0].connect('size-allocate',
+            function(w, rect) {
+                app.commandOutputQueue.widget.margin_bottom = rect.height - 1;
+            });
+
         this._titlebarRight = builder.get_object('titlebar_right');
         this._titlebarLeft = builder.get_object('titlebar_left');
 
         this._titleLabel = builder.get_object('title_label');
         this._subtitleLabel = builder.get_object('subtitle_label');
 
-        this._selectionRevealer = builder.get_object('selection_toolbar_revealer');
+        this._selectionActionBar = builder.get_object('selection_action_bar');
+
+        // slightly hackish:
+        // add the content of the internal revealer to size group
+        sizeGroup.add_widget(this._selectionActionBar.get_child().get_child());
+
         this._joinMenuButton = builder.get_object('join_menu_button');
         this._showUserListButton = builder.get_object('show_user_list_button');
         this._revealer = builder.get_object('room_list_revealer');
