@@ -16,6 +16,8 @@ const MessageDialog = new Lang.Class({
     _init: function() {
         this._createWidget();
 
+        this._settings = new Gio.Settings({ schema: 'org.gnome.polari' });
+
         this._accounts = {};
         AccountsMonitor.getDefault().dupAccounts().forEach(Lang.bind(this,
             function(a) {
@@ -30,15 +32,22 @@ const MessageDialog = new Lang.Class({
             });
         for (let i = 0; i < names.length; i++)
             this._connectionCombo.append_text(names[i]);
-        this._connectionCombo.set_active(0);
         this._connectionCombo.sensitive = names.length > 1;
+
+        let factory = Tp.AccountManager.dup().get_factory();
+        let lastUsed = factory.ensure_account(this._settings.get_string('last-used-account'), []);
+        let activeIndex = lastUsed ? names.indexOf(lastUsed.display_name) : 0;
+        this._connectionCombo.set_active(activeIndex);
+
         this._updateCanConfirm();
         this._updateRecentList([]);
+
+        this._nameEntry.grab_focus();
     },
 
     _createWidget: function() {
         let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/polari/message-user-dialog.ui');
+        builder.add_from_resource('/org/gnome/Polari/message-user-dialog.ui');
 
         this.widget = builder.get_object('message_user_dialog');
 
@@ -152,6 +161,9 @@ const MessageDialog = new Lang.Class({
         let selected = this._connectionCombo.get_active_text();
         let account = this._accounts[selected];
 
+        this._settings.set_string('last-used-account',
+                                  account.get_object_path());
+
         let user = this._nameEntry.get_text();
 
         let app = Gio.Application.get_default();
@@ -167,5 +179,7 @@ const MessageDialog = new Lang.Class({
             let sensitive = this._connectionCombo.get_active() > -1  &&
                             this._nameEntry.get_text_length() > 0;
             this._messageButton.sensitive = sensitive;
+            this.widget.set_default_response(sensitive ? Gtk.ResponseType.OK
+                                                       : Gtk.ResponseType.NONE);
     }
 });
